<?php

namespace News\News\Http\Controllers;

use App\Http\Controllers\PublicController as CMSPublicController;
use News\News\Interfaces\NewsRepositoryInterface;

class NewsPublicController extends CMSPublicController
{
    /**
     * Constructor.
     *
     * @param type \News\News\Interfaces\NewsRepositoryInterface $news
     *
     * @return type
     */
    public function __construct(NewsRepositoryInterface $news)
    {
        $this->repository = $news;
        parent::__construct();
    }

    /**
     * Show news's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $news = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        return $this->theme->of('news::public.news.index', compact('news'))->render();
    }

    /**
     * Show news.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $news = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('news::public.news.show', compact('news'))->render();
    }
}
